package cn.fw.hestia.rpc.passport

import cn.fw.hestia.common.constant.Constant
import cn.fw.hestia.common.utils.StringUtils.isValid
import cn.fw.hestia.rpc.passport.dto.TMParam
import cn.fw.passport.sdk.api.WxMpTemplateMessageApi
import cn.fw.passport.sdk.api.param.WxMpTempMessageData
import cn.fw.passport.sdk.api.param.WxMpTempMessageParam
import com.alibaba.fastjson.JSONArray
import org.slf4j.LoggerFactory
import org.springframework.stereotype.Service

/**
 * passport系统-模板消息服务
 *
 *
 * create at 2019-05-15
 *
 * @author kurisu
 */
@Service
class TemplateMessageService(private val wxMpTemplateMessageApi: WxMpTemplateMessageApi) {
    private val log = LoggerFactory.getLogger(this::class.java)

    /**
     * 发送消息通知
     *
     * @param messageParam
     */
    fun sendTemplateMessage(messageParam: TMParam): String {
        log.info("发送通知，SceneToken ：{}", messageParam.sceneToken)
        try {
            val param = WxMpTempMessageParam()
            param.cusId = messageParam.memberId
            param.tempId = messageParam.templateCode
            if (isValid(messageParam.keywords)) {
                val keywords = JSONArray.parseArray(
                    messageParam.keywords,
                    WxMpTempMessageData::class.java
                )
                param.keyWordList = keywords
            }
            val pagePath = getPagePath(messageParam.path, messageParam.sceneToken)
            if (isValid(pagePath)) {
                param.pagePath = pagePath
            }
            val msg = wxMpTemplateMessageApi.send(param)
            if (!msg.isSuccess) {
                log.error("【passport系统】发送模板消息失败：{}", msg.result)
                return msg.result
            }
            return Constant.SUCCEED_STR
        } catch (e: Exception) {
            log.error("发送模板消息失败", e)
            return "系统调用异常"
        }
    }


    private fun getPagePath(path: String?, sceneToken: Long?): String? {
        return if (!path.isNullOrEmpty()) {
            val sb = StringBuilder(path)
            if (isValid(sceneToken)) {
                sb.append("?sceneToken=").append(sceneToken)
            }
            sb.toString()
        } else {
            null
        }
    }
}