package cn.fw.hestia.sdk.api;

import cn.fw.data.base.domain.common.Message;
import cn.fw.hestia.sdk.params.TemplateMessageParam;
import cn.fw.hestia.sdk.params.ValidList;
import cn.fw.hestia.sdk.result.SendResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * @author : kurisu
 * @className : IMessageCenterService
 * @description :
 * @date: 2021-09-23 15:27
 */
@FeignClient(value = "fw-hestia", path = "/api/hestia/mc")
public interface IMessageCenterService {

    /**
     * 发送模板消息
     *
     * @param templateMessageParam
     * @return
     */
    @PostMapping("/send")
    Message<SendResult> send(@Valid @RequestBody TemplateMessageParam templateMessageParam);

    /**
     * 批量发送模板消息
     *
     * @param paramList
     * @return
     */
    @PostMapping("/sendBatch")
    Message<List<SendResult>> sendBatch(@RequestBody @Valid ValidList<TemplateMessageParam> paramList);

    /**
     * 撤回消息
     *
     * @param sceneToken
     * @return
     */
    @DeleteMapping("/revoke")
    Message<Boolean> revokeMessage(@NotNull(message = "Token不能为空") Long sceneToken);
}
