package cn.fw.hestia.server.config

import com.baomidou.mybatisplus.core.incrementer.IdentifierGenerator
import com.github.yitter.contract.IdGeneratorOptions
import com.github.yitter.idgen.YitIdHelper
import org.springframework.context.annotation.Scope
import org.springframework.stereotype.Component

/**
 * 自定义id生成器
 * @author kurisu
 */
@Component
@Scope("singleton")
class CustomIdIdentifierGenerator : IdentifierGenerator {
    override fun nextId(entity: Any): Long {
        //可以将当前传入的class全类名来作为bizKey,或者提取参数来生成bizKey进行分布式Id调用生成.
        val bizKey = entity.javaClass.name
        //根据bizKey调用分布式ID生成
        return YitIdHelper.nextId()
    }

    companion object {
        init {
            //全局初始化设置WorkerId，默认最大2^16-1，可通过调整 WorkerIdBitLength 增加最大值
            val options = IdGeneratorOptions()
            options.WorkerId = 1
            options.WorkerIdBitLength = 6
            YitIdHelper.setIdGenerator(options)
            println("------------------初始化IdentifierGenerator------------------------")
        }
    }
}