package cn.fw.hestia.server.controller.api

import cn.fw.common.businessvalidator.Validator.BV
import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.util.ResultBuilder.success
import cn.fw.data.base.domain.common.Message
import cn.fw.hestia.common.utils.MessageFormatUtil
import cn.fw.hestia.sdk.api.IMessageCenterService
import cn.fw.hestia.sdk.params.TemplateMessageParam
import cn.fw.hestia.sdk.params.ValidList
import cn.fw.hestia.sdk.result.SendResult
import cn.fw.hestia.service.buz.MessageCenterBizService
import org.springframework.beans.factory.annotation.Value
import org.springframework.web.bind.annotation.*
import javax.validation.Valid
import javax.validation.constraints.NotNull

/**
 * @author : kurisu
 * @className : MessageCenterServiceImpl
 * @description :
 * @date: 2021-09-23 15:39
 */
@RestController
@RequestMapping("/api/hestia/mc")
class MessageCenterServiceImpl(
    private val messageCenterBizService: MessageCenterBizService,
    @Value("\${task.max-size}") private val maxSize: Int = 0
) :
    IMessageCenterService {

    @PostMapping("/send")
    @ControllerMethod("发送模板消息")
    override fun send(@RequestBody templateMessageParam: @Valid TemplateMessageParam): Message<SendResult> {
        return success(
            messageCenterBizService.saveMessage(
                templateMessageParam
            )
        )
    }

    @PostMapping("/sendBatch")
    @ControllerMethod("批量发送模板消息")
    override fun sendBatch(@RequestBody paramList: @Valid ValidList<TemplateMessageParam>?): Message<List<SendResult>> {
        BV.isNotEmpty(paramList) { "消息列表不能为空" }
        BV.isTrue(
            paramList!!.size <= maxSize
        ) { MessageFormatUtil.messageFormatTransfer("最多支持一次性发送{0}条", maxSize) }
        return success(
            messageCenterBizService.saveBatchMessage(
                paramList
            )
        )
    }

    @DeleteMapping("/revoke")
    @ControllerMethod("撤回消息")
    override fun revokeMessage(sceneToken: @NotNull(message = "Token不能为空") Long?): Message<Boolean> {
        return success(messageCenterBizService.revokeMessage(sceneToken))
    }
}