package cn.fw.hestia.server.controller.common

import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.util.ResultBuilder.success
import cn.fw.data.base.domain.common.Message
import cn.fw.hestia.rpc.member.MemberRpcService
import cn.fw.hestia.service.buz.MessageCenterBizService
import cn.fw.security.auth.client.annotation.Authorization
import cn.fw.security.auth.client.enums.AuthType
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.*
import javax.validation.constraints.NotNull

/**
 * @author : kurisu
 * @className : MessageCenterController
 * @description :
 * @date: 2021-09-23 15:39
 */
@Validated
@RestController
@Authorization(AuthType.NONE)
@RequestMapping("/common/message")
class CommonController(
    private val messageCenterBizService: MessageCenterBizService,
    private val memberRpcService: MemberRpcService
) {
    @PostMapping("/send")
    @ControllerMethod("手动发送消息")
    fun manualSend(sceneToken: @NotNull(message = "sceneToken不能为空") Long?): Message<String> {
        return success(messageCenterBizService.manualSend(sceneToken))
    }

    @get:ControllerMethod("查询模板码")
    @get:GetMapping("/query/code")
    val code: Message<String>
        get() = success(messageCenterBizService.rdsTemplateCode)

    @ControllerMethod("查询手机号归属地")
    @GetMapping("/query/mobile")
    fun mobileAttr(@RequestParam(value = "mobile") mobile: String): Message<String> =
        success(memberRpcService.attribution(mobile))
}