package cn.fw.hestia.server.controller.wx

import cn.fw.common.page.AppPage
import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.auth.annotation.CurrentUser
import cn.fw.common.web.util.ResultBuilder.success
import cn.fw.data.base.domain.common.Message
import cn.fw.hestia.domain.vo.HistoryQuery
import cn.fw.hestia.domain.vo.MessageHistoryVO
import cn.fw.hestia.service.buz.MessageCenterBizService
import cn.fw.security.auth.client.annotation.Authorization
import cn.fw.security.auth.client.enums.AuthType
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.GetMapping
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController
import javax.validation.constraints.NotNull

/**
 * @author : kurisu
 * @className : MessageCenterController
 * @description :
 * @date: 2021-09-23 15:39
 */
@Validated
@RestController
@Authorization(AuthType.WECHAT)
@RequestMapping("/wx/message")
class MessageCenterController(private val messageCenterBizService: MessageCenterBizService) {
    @GetMapping("/unread")
    @ControllerMethod("查询消息未读数")
    fun send(@CurrentUser userId: Long?): Message<Int> {
        return success(messageCenterBizService.unreadCount(userId))
    }

    @GetMapping("/query/pageParams")
    @ControllerMethod("查询小程序页面的参数")
    fun queryPageParams(sceneToken: @NotNull(message = "sceneToken不能为空") Long?): Message<Map<String, String>> {
        return success(messageCenterBizService.queryPageParams(sceneToken))
    }

    @GetMapping("/query/history")
    @ControllerMethod("查询消息历史记录")
    fun queryHistory(query: HistoryQuery): Message<AppPage<MessageHistoryVO>> {
        return success(messageCenterBizService.queryHistory(query))
    }
}